@@ -30,7 +30,8 @@ SpatialToPBS <- structure(function#converts spatial objects as defined in packag
   return(list(xy=xy, bb=b, fun=fun))
 ### list with elements xy = converted object, bb = bounding box, fun = plot function
 }, ex = function(){
-  data(NYleukemia)
+if (0) {
+  data("NYleukemia", envir = environment())
   population <- NYleukemia$data$population
   cases <- NYleukemia$data$cases
   mapNY <- GetMap(center=c(lat=42.67456,lon=-76.00365), destfile = "NYstate.png", maptype = "mobile", zoom=9)
@@ -39,6 +40,6 @@ SpatialToPBS <- structure(function#converts spatial objects as defined in packag
   NYpolys = SpatialToPBS(NYleukemia$spatial.polygon)
   PlotPolysOnStaticMap(mapNY, NYpolys$xy, col = clrStuff$colcode, add = FALSE)
   legend("topleft", legend = clrStuff$legend, fill = clrStuff$fill, bg = rgb(0.1,0.1,0.1,0.3))
-  
+}
   
 })
